"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.mdb.postgresql.v1.database_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster that the database belongs to.
    To get the cluster ID use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the PostgreSQL Database resource to return.
    To get the name of the database use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___GetDatabaseRequest = GetDatabaseRequest

@typing.final
class ListDatabasesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster to list databases in.
    To get the cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDatabasesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, Set [page_token] to the [ListDatabasesResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDatabasesRequest = ListDatabasesRequest

@typing.final
class ListDatabasesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDatabasesRequest.page_size], use the [next_page_token] as the value
    for the [ListDatabasesRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.database_pb2.Database]:
        """List of PostgreSQL Database resources."""

    def __init__(
        self,
        *,
        databases: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.database_pb2.Database] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["databases", b"databases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDatabasesResponse = ListDatabasesResponse

@typing.final
class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster to create a database in.
    To get the cluster ID use a [ClusterService.List] request.
    """
    @property
    def database_spec(self) -> yandex.cloud.mdb.postgresql.v1.database_pb2.DatabaseSpec:
        """Configuration of the database to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_spec: yandex.cloud.mdb.postgresql.v1.database_pb2.DatabaseSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["database_spec", b"database_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_spec", b"database_spec"]) -> None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

@typing.final
class CreateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster where a database is being created."""
    database_name: builtins.str
    """Name of the PostgreSQL database that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___CreateDatabaseMetadata = CreateDatabaseMetadata

@typing.final
class UpdateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    NEW_DATABASE_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster to update a database in.
    To get the cluster ID use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the database to update.
    To get the name of the database use a [DatabaseService.List] request.
    """
    new_database_name: builtins.str
    """Optional. New name of the database."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Database resource should be updated."""

    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.database_pb2.Extension]:
        """PostgreSQL extensions that should be enabled for the database.

        If the field is sent, the list of enabled extensions is rewritten entirely.
        Therefore, to disable an active extension you should simply send the list omitting this extension.
        """

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Deletion Protection inhibits deletion of the database

        Default value: `unspecified` (inherits cluster's deletion_protection)
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        new_database_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        extensions: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.database_pb2.Extension] | None = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "deletion_protection", b"deletion_protection", "extensions", b"extensions", "new_database_name", b"new_database_name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDatabaseRequest = UpdateDatabaseRequest

@typing.final
class UpdateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster where a database is being updated."""
    database_name: builtins.str
    """Name of the PostgreSQL database that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___UpdateDatabaseMetadata = UpdateDatabaseMetadata

@typing.final
class DeleteDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster to delete a database in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the database to delete.
    To get the name of the database, use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseRequest = DeleteDatabaseRequest

@typing.final
class DeleteDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster where a database is being deleted."""
    database_name: builtins.str
    """Name of the PostgreSQL database that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseMetadata = DeleteDatabaseMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/foundation_models/v1/text_generation/text_generation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ai.foundation_models.v1 import text_common_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__common__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/ai/foundation_models/v1/text_generation/text_generation_service.proto\x12$yandex.cloud.ai.foundation_models.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x36yandex/cloud/ai/foundation_models/v1/text_common.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\xbc\x01\n\x11\x43ompletionRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12S\n\x12\x63ompletion_options\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.ai.foundation_models.v1.CompletionOptions\x12?\n\x08messages\x18\x03 \x03(\x0b\x32-.yandex.cloud.ai.foundation_models.v1.Message\"\xb7\x01\n\x12\x43ompletionResponse\x12G\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.ai.foundation_models.v1.Alternative\x12\x41\n\x05usage\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.ai.foundation_models.v1.ContentUsage\x12\x15\n\rmodel_version\x18\x03 \x01(\t\"2\n\x0fTokenizeRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"f\n\x10TokenizeResponse\x12;\n\x06tokens\x18\x01 \x03(\x0b\x32+.yandex.cloud.ai.foundation_models.v1.Token\x12\x15\n\rmodel_version\x18\x02 \x01(\t2\xc7\x01\n\x15TextGenerationService\x12\xad\x01\n\nCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a\x38.yandex.cloud.ai.foundation_models.v1.CompletionResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/foundationModels/v1/completion:\x01*0\x01\x32\xd0\x01\n\x1aTextGenerationAsyncService\x12\xb1\x01\n\nCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x14\x12\x12\x43ompletionResponse\x82\xd3\xe4\x93\x02)\"$/foundationModels/v1/completionAsync:\x01*2\xf4\x02\n\x10TokenizerService\x12\xa3\x01\n\x08Tokenize\x12\x35.yandex.cloud.ai.foundation_models.v1.TokenizeRequest\x1a\x36.yandex.cloud.ai.foundation_models.v1.TokenizeResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/foundationModels/v1/tokenize:\x01*\x12\xb9\x01\n\x12TokenizeCompletion\x12\x37.yandex.cloud.ai.foundation_models.v1.CompletionRequest\x1a\x36.yandex.cloud.ai.foundation_models.v1.TokenizeResponse\"2\x82\xd3\xe4\x93\x02,\"\'/foundationModels/v1/tokenizeCompletion:\x01*B\x96\x01\n(yandex.cloud.api.ai.foundation_models.v1Zjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_generation;foundation_modelsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.ai.foundation_models.v1Zjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_generation;foundation_models'
  _TEXTGENERATIONSERVICE.methods_by_name['Completion']._options = None
  _TEXTGENERATIONSERVICE.methods_by_name['Completion']._serialized_options = b'\202\323\344\223\002$\"\037/foundationModels/v1/completion:\001*'
  _TEXTGENERATIONASYNCSERVICE.methods_by_name['Completion']._options = None
  _TEXTGENERATIONASYNCSERVICE.methods_by_name['Completion']._serialized_options = b'\262\322*\024\022\022CompletionResponse\202\323\344\223\002)\"$/foundationModels/v1/completionAsync:\001*'
  _TOKENIZERSERVICE.methods_by_name['Tokenize']._options = None
  _TOKENIZERSERVICE.methods_by_name['Tokenize']._serialized_options = b'\202\323\344\223\002\"\"\035/foundationModels/v1/tokenize:\001*'
  _TOKENIZERSERVICE.methods_by_name['TokenizeCompletion']._options = None
  _TOKENIZERSERVICE.methods_by_name['TokenizeCompletion']._serialized_options = b'\202\323\344\223\002,\"\'/foundationModels/v1/tokenizeCompletion:\001*'
  _globals['_COMPLETIONREQUEST']._serialized_start=285
  _globals['_COMPLETIONREQUEST']._serialized_end=473
  _globals['_COMPLETIONRESPONSE']._serialized_start=476
  _globals['_COMPLETIONRESPONSE']._serialized_end=659
  _globals['_TOKENIZEREQUEST']._serialized_start=661
  _globals['_TOKENIZEREQUEST']._serialized_end=711
  _globals['_TOKENIZERESPONSE']._serialized_start=713
  _globals['_TOKENIZERESPONSE']._serialized_end=815
  _globals['_TEXTGENERATIONSERVICE']._serialized_start=818
  _globals['_TEXTGENERATIONSERVICE']._serialized_end=1017
  _globals['_TEXTGENERATIONASYNCSERVICE']._serialized_start=1020
  _globals['_TEXTGENERATIONASYNCSERVICE']._serialized_end=1228
  _globals['_TOKENIZERSERVICE']._serialized_start=1231
  _globals['_TOKENIZERSERVICE']._serialized_end=1603
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MlModelType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MlModelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MlModelType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ML_MODEL_TYPE_UNSPECIFIED: _MlModelType.ValueType  # 0
    ML_MODEL_TYPE_CATBOOST: _MlModelType.ValueType  # 1
    """CatBoost model."""

class MlModelType(_MlModelType, metaclass=_MlModelTypeEnumTypeWrapper): ...

ML_MODEL_TYPE_UNSPECIFIED: MlModelType.ValueType  # 0
ML_MODEL_TYPE_CATBOOST: MlModelType.ValueType  # 1
"""CatBoost model."""
global___MlModelType = MlModelType

@typing.final
class MlModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the the model."""
    cluster_id: builtins.str
    """ID of the ClickHouse cluster that the model belongs to."""
    type: global___MlModelType.ValueType
    """Type of the model."""
    uri: builtins.str
    """Model file URL. You can only use models stored in Object Storage."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        type: global___MlModelType.ValueType = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "type", b"type", "uri", b"uri"]) -> None: ...

global___MlModel = MlModel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IpPermissionAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IpPermissionActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IpPermissionAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IP_PERMISSION_ACTION_UNSPECIFIED: _IpPermissionAction.ValueType  # 0
    ADD: _IpPermissionAction.ValueType  # 1
    """Addition of an ip permission."""
    REMOVE: _IpPermissionAction.ValueType  # 2
    """Removal of an ip permission."""

class IpPermissionAction(_IpPermissionAction, metaclass=_IpPermissionActionEnumTypeWrapper): ...

IP_PERMISSION_ACTION_UNSPECIFIED: IpPermissionAction.ValueType  # 0
ADD: IpPermissionAction.ValueType  # 1
"""Addition of an ip permission."""
REMOVE: IpPermissionAction.ValueType  # 2
"""Removal of an ip permission."""
global___IpPermissionAction = IpPermissionAction

@typing.final
class IpPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[IpPermission._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: IpPermission._Action.ValueType  # 0
        PULL: IpPermission._Action.ValueType  # 1
        PUSH: IpPermission._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    ACTION_UNSPECIFIED: IpPermission.Action.ValueType  # 0
    PULL: IpPermission.Action.ValueType  # 1
    PUSH: IpPermission.Action.ValueType  # 2

    ACTION_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    action: global___IpPermission.Action.ValueType
    ip: builtins.str
    def __init__(
        self,
        *,
        action: global___IpPermission.Action.ValueType = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "ip", b"ip"]) -> None: ...

global___IpPermission = IpPermission

@typing.final
class IpPermissionDelta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    IP_PERMISSION_FIELD_NUMBER: builtins.int
    action: global___IpPermissionAction.ValueType
    """The action that is being performed on an ip permission."""
    @property
    def ip_permission(self) -> global___IpPermission:
        """Ip permission."""

    def __init__(
        self,
        *,
        action: global___IpPermissionAction.ValueType = ...,
        ip_permission: global___IpPermission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ip_permission", b"ip_permission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "ip_permission", b"ip_permission"]) -> None: ...

global___IpPermissionDelta = IpPermissionDelta



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ImbalancePoint(google.protobuf.message.Message):
    """Test imbalance point."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AT_FIELD_NUMBER: builtins.int
    RPS_FIELD_NUMBER: builtins.int
    rps: builtins.int
    """Imbalance moment RPS."""
    @property
    def at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Imbalance moment timestamp."""

    def __init__(
        self,
        *,
        at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["at", b"at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["at", b"at", "rps", b"rps"]) -> None: ...

global___ImbalancePoint = ImbalancePoint



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.compute.v1 import host_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2
from yandex.cloud.compute.v1 import host_group_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class HostGroupServiceStub(object):
    """A set of methods for managing groups of dedicated hosts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.GetHostGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2.HostGroup.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.CreateHostGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.DeleteHostGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsResponse.FromString,
                )
        self.ListInstances = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/ListInstances',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesResponse.FromString,
                )
        self.ListHosts = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/ListHosts',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsResponse.FromString,
                )
        self.UpdateHost = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/UpdateHost',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupHostRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.compute.v1.HostGroupService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class HostGroupServiceServicer(object):
    """A set of methods for managing groups of dedicated hosts.
    """

    def Get(self, request, context):
        """Returns the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of host groups in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a host group in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInstances(self, request, context):
        """Lists instances that belongs to the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListHosts(self, request, context):
        """Lists hosts that belongs to the specified host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateHost(self, request, context):
        """Update host
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the host group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HostGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.GetHostGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2.HostGroup.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.CreateHostGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.DeleteHostGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsResponse.SerializeToString,
            ),
            'ListInstances': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstances,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesResponse.SerializeToString,
            ),
            'ListHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListHosts,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsResponse.SerializeToString,
            ),
            'UpdateHost': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateHost,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupHostRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.HostGroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HostGroupService(object):
    """A set of methods for managing groups of dedicated hosts.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.GetHostGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2.HostGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.CreateHostGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.DeleteHostGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInstances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/ListInstances',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupInstancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/ListHosts',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.ListHostGroupHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/UpdateHost',
            yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__service__pb2.UpdateHostGroupHostRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.HostGroupService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2
import yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ConnectionServiceStub:
    """A set of methods for managing API Gateway WebSocket connections."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.GetConnectionRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2.Connection,
    ]
    """Returns the specified connection info."""

    Send: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionResponse,
    ]
    """Sends data to the specified connection."""

    Disconnect: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectResponse,
    ]
    """Disconnects the specified connection."""

class ConnectionServiceAsyncStub:
    """A set of methods for managing API Gateway WebSocket connections."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.GetConnectionRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2.Connection,
    ]
    """Returns the specified connection info."""

    Send: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionResponse,
    ]
    """Sends data to the specified connection."""

    Disconnect: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectRequest,
        yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectResponse,
    ]
    """Disconnects the specified connection."""

class ConnectionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing API Gateway WebSocket connections."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.GetConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2.Connection, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2.Connection]]:
        """Returns the specified connection info."""

    @abc.abstractmethod
    def Send(
        self,
        request: yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionResponse, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.SendToConnectionResponse]]:
        """Sends data to the specified connection."""

    @abc.abstractmethod
    def Disconnect(
        self,
        request: yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectResponse, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2.DisconnectResponse]]:
        """Disconnects the specified connection."""

def add_ConnectionServiceServicer_to_server(servicer: ConnectionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.gpu_cluster_pb2
import yandex.cloud.compute.v1.gpu_cluster_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class GpuClusterServiceStub:
    """A set of methods for managing GPU clusters."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.GetGpuClusterRequest,
        yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster,
    ]
    """Returns the specified GPU cluster.

    To get the list of available GPU clusters, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersResponse,
    ]
    """Retrieves the list of GPU clusters in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.CreateGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a GPU cluster in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.UpdateGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified GPU cluster.

    Currently only name, description and labels can be updated.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.DeleteGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified GPU cluster.

    GPU cluster can be deleted only if it doesn't have any instances associated with it.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsResponse,
    ]
    """Lists operations for the specified GPU cluster."""

    ListInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesResponse,
    ]
    """List instances created in this GPU cluster."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the GPU cluster.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the GPU cluster."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the GPU cluster."""

class GpuClusterServiceAsyncStub:
    """A set of methods for managing GPU clusters."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.GetGpuClusterRequest,
        yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster,
    ]
    """Returns the specified GPU cluster.

    To get the list of available GPU clusters, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersResponse,
    ]
    """Retrieves the list of GPU clusters in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.CreateGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a GPU cluster in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.UpdateGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified GPU cluster.

    Currently only name, description and labels can be updated.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.DeleteGpuClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified GPU cluster.

    GPU cluster can be deleted only if it doesn't have any instances associated with it.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsResponse,
    ]
    """Lists operations for the specified GPU cluster."""

    ListInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesRequest,
        yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesResponse,
    ]
    """List instances created in this GPU cluster."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the GPU cluster.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the GPU cluster."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the GPU cluster."""

class GpuClusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing GPU clusters."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.GetGpuClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster, collections.abc.Awaitable[yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster]]:
        """Returns the specified GPU cluster.

        To get the list of available GPU clusters, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClustersResponse]]:
        """Retrieves the list of GPU clusters in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.CreateGpuClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a GPU cluster in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.UpdateGpuClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified GPU cluster.

        Currently only name, description and labels can be updated.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.DeleteGpuClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified GPU cluster.

        GPU cluster can be deleted only if it doesn't have any instances associated with it.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterOperationsResponse]]:
        """Lists operations for the specified GPU cluster."""

    @abc.abstractmethod
    def ListInstances(
        self,
        request: yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.gpu_cluster_service_pb2.ListGpuClusterInstancesResponse]]:
        """List instances created in this GPU cluster."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the GPU cluster.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the GPU cluster."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the GPU cluster."""

def add_GpuClusterServiceServicer_to_server(servicer: GpuClusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Disk(google.protobuf.message.Message):
    """A Disk resource. For more information, see [Disks](/docs/compute/concepts/disk)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Disk._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Disk._Status.ValueType  # 0
        CREATING: Disk._Status.ValueType  # 1
        """Disk is being created."""
        READY: Disk._Status.ValueType  # 2
        """Disk is ready to use."""
        ERROR: Disk._Status.ValueType  # 3
        """Disk encountered a problem and cannot operate."""
        DELETING: Disk._Status.ValueType  # 4
        """Disk is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Disk.Status.ValueType  # 0
    CREATING: Disk.Status.ValueType  # 1
    """Disk is being created."""
    READY: Disk.Status.ValueType  # 2
    """Disk is ready to use."""
    ERROR: Disk.Status.ValueType  # 3
    """Disk encountered a problem and cannot operate."""
    DELETING: Disk.Status.ValueType  # 4
    """Disk is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_IMAGE_ID_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    INSTANCE_IDS_FIELD_NUMBER: builtins.int
    DISK_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the disk."""
    folder_id: builtins.str
    """ID of the folder that the disk belongs to."""
    name: builtins.str
    """Name of the disk. 1-63 characters long."""
    description: builtins.str
    """Description of the disk. 0-256 characters long."""
    type_id: builtins.str
    """ID of the disk type."""
    zone_id: builtins.str
    """ID of the availability zone where the disk resides."""
    size: builtins.int
    """Size of the disk, specified in bytes."""
    block_size: builtins.int
    """Block size of the disk, specified in bytes."""
    status: global___Disk.Status.ValueType
    """Current status of the disk."""
    source_image_id: builtins.str
    """ID of the image that was used for disk creation."""
    source_snapshot_id: builtins.str
    """ID of the snapshot that was used for disk creation."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to this resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.

        The correct license ID is generated by the platform. IDs are inherited by new resources created from this resource.

        If you know the license IDs, specify them when you create the image.
        For example, if you create a disk image using a third-party utility and load it into Object Storage, the license IDs will be lost.
        You can specify them in the [yandex.cloud.compute.v1.ImageService.Create] request.
        """

    @property
    def instance_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Array of instances to which the disk is attached."""

    @property
    def disk_placement_policy(self) -> global___DiskPlacementPolicy:
        """Placement policy configuration."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        size: builtins.int = ...,
        block_size: builtins.int = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Disk.Status.ValueType = ...,
        source_image_id: builtins.str = ...,
        source_snapshot_id: builtins.str = ...,
        instance_ids: collections.abc.Iterable[builtins.str] | None = ...,
        disk_placement_policy: global___DiskPlacementPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "disk_placement_policy", b"disk_placement_policy", "source", b"source", "source_image_id", b"source_image_id", "source_snapshot_id", b"source_snapshot_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "created_at", b"created_at", "description", b"description", "disk_placement_policy", b"disk_placement_policy", "folder_id", b"folder_id", "id", b"id", "instance_ids", b"instance_ids", "labels", b"labels", "name", b"name", "product_ids", b"product_ids", "size", b"size", "source", b"source", "source_image_id", b"source_image_id", "source_snapshot_id", b"source_snapshot_id", "status", b"status", "type_id", b"type_id", "zone_id", b"zone_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["source_image_id", "source_snapshot_id"] | None: ...

global___Disk = Disk

@typing.final
class DiskPlacementPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_PARTITION_FIELD_NUMBER: builtins.int
    placement_group_id: builtins.str
    """Placement group ID."""
    placement_group_partition: builtins.int
    def __init__(
        self,
        *,
        placement_group_id: builtins.str = ...,
        placement_group_partition: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["placement_group_id", b"placement_group_id", "placement_group_partition", b"placement_group_partition"]) -> None: ...

global___DiskPlacementPolicy = DiskPlacementPolicy

@typing.final
class DiskPlacementPolicyChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    DISK_PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """Disk ID."""
    @property
    def disk_placement_policy(self) -> global___DiskPlacementPolicy:
        """Placement policy configuration for given disk."""

    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        disk_placement_policy: global___DiskPlacementPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_placement_policy", b"disk_placement_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id", "disk_placement_policy", b"disk_placement_policy"]) -> None: ...

global___DiskPlacementPolicyChange = DiskPlacementPolicyChange
